// src/index.ts
import { Client } from "@modelcontextprotocol/sdk/client/index.js";
import {
  StdioClientTransport
} from "@modelcontextprotocol/sdk/client/stdio.js";
import { jsonSchemaToZod } from "json-schema-to-zod";
var McpFunctionCallingAdapter = class {
  constructor(name, version, parameters) {
    this.parameters = parameters;
    this.client = new Client(
      {
        name,
        version
      },
      {
        capabilities: {
          prompts: {},
          resources: {},
          tools: {}
        }
      }
    );
  }
  tools = [];
  client;
  async startServers() {
    for (const [name, serverParameter] of Object.entries(this.parameters)) {
      const transport = new StdioClientTransport(serverParameter);
      await this.client.connect(transport);
      console.log(`${name} is successfully started!`);
    }
    const { tools } = await this.client.listTools();
    this.tools = tools;
  }
  async clean() {
    await this.client.close();
  }
  getTools() {
    return this.tools.map(({ name, description, inputSchema }) => ({
      name,
      description,
      jsonSchema: inputSchema,
      zodSchema: jsonSchemaToZod(inputSchema)
    }));
  }
  isRegisteredTool(name) {
    return this.tools.map(({ name: name2 }) => name2).includes(name);
  }
  async executeTool(name, args) {
    const toolResult = await this.client.callTool({
      name,
      arguments: args
    });
    return {
      _meta: toolResult._meta,
      content: toolResult.content,
      isError: toolResult.isError,
      toolResult: toolResult.toolResult
    };
  }
};
export {
  McpFunctionCallingAdapter
};
//# sourceMappingURL=index.js.map